<?php

namespace App\Http\Resources;

use App\Models\Category;
use App\Models\Favourite;
use Carbon\Carbon;
use Illuminate\Http\Resources\Json\JsonResource;

class ProductsResource extends JsonResource
{
    /**
     * Transform the resource into an array.
     *
     * @param \Illuminate\Http\Request $request
     * @return array
     */
    public function toArray($request)
    {

        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $category = Category::find($this->category_id);
        $parent_category = Category::find($category->parent_id);

        if ($parent_category) {
            $categories = Category::whereParentId($parent_category->id)->get();
        } else {
            $categories = Category::whereParentId($category->id)->get();
        }

        $hide_mobile = '';
        $ad_type = '';
        $car_status = '';
        $fetis = '';
        $fuel = '';
        $double = '';
        $determine_price = '';
        if ($lang == 'ar') {

            if ($this->hide_mobile && $this->hide_mobile == 'true') {
                $hide_mobile = 'نعم';
            } else {
                $hide_mobile = 'لا';
            }
            if ($this->ad_type && $this->ad_type == 'buy') {
                $ad_type = 'بيع';
            } else {
                $ad_type = 'تنازل';
            }
            if ($this->car_status && $this->car_status == 'used') {
                $car_status = 'استخدام';
            } elseif ($this->car_status && $this->car_status == 'accident') {
                $car_status = "حادثة";
            } elseif ($this->car_status && $this->car_status == 'new') {
                $car_status = "جديدة";
            }
            if ($this->fetis && $this->fetis == 'manual') {
                $fetis = "مانوال";
            } elseif ($this->fetis && $this->fetis == 'automatic') {
                $fetis = "أوتوماتيك";
            }
            if ($this->fuel && $this->fuel == 'gasoline') {
                $fuel = "بنزين";
            } elseif ($this->fuel && $this->fuel == 'hybrid') {
                $fuel = "هجين";
            } elseif ($this->fuel && $this->fuel == 'diesel') {
                $fuel = "ديزل";
            }
            if ($this->double && $this->double == 'true') {
                $double = "نعم";
            } elseif ($this->double && $this->double == 'false') {
                $double = 'لا';
            }
            if ($this->determine_price && $this->determine_price == 'true') {
                $determine_price = 'نعم';
            } elseif ($this->determine_price && $this->determine_price == 'false') {
                $determine_price = 'لا';
            }


        } else {

            if ($this->hide_mobile && $this->hide_mobile == 'true') {
                $hide_mobile = 'Yes';
            } else {
                $hide_mobile = 'No';
            }
            if ($this->ad_type && $this->ad_type == 'buy') {
                $ad_type = 'Buy';
            } else {
                $ad_type = 'Waiver';
            }
            if ($this->car_status && $this->car_status == 'used') {
                $car_status = 'Used';
            } elseif ($this->car_status && $this->car_status == 'accident') {
                $car_status = "Accident";
            } elseif ($this->car_status && $this->car_status == 'new') {
                $car_status = "New";
            }
            if ($this->fetis && $this->fetis == 'manual') {
                $fetis = "Manual";
            } elseif ($this->fetis && $this->fetis == 'automatic') {
                $fetis = "Automatic";
            }
            if ($this->fuel && $this->fuel == 'gasoline') {
                $fuel = "Gasoline";
            } elseif ($this->fuel && $this->fuel == 'hybrid') {
                $fuel = "Hybrid";
            } elseif ($this->fuel && $this->fuel == 'diesel') {
                $fuel = "Diesel";
            }
            if ($this->double && $this->double == 'true') {
                $double = "Yes";
            } elseif ($this->double && $this->double == 'false') {
                $double = 'No';
            }
            if ($this->determine_price && $this->determine_price == 'true') {
                $determine_price = 'True';
            } elseif ($this->determine_price && $this->determine_price == 'false') {
                $determine_price = 'No';
            }


        }


        return [
            'id' => $this->id,
            'title' => $this->title,
            'category_id' => (integer)$this->category_id,
            'category_name' => $this->category->name[$lang],
            'category_car_option' => $this->category->car_option,
            'city_id' => (integer)$this->city_id ? (integer)$this->city_id : 0,
            'city_name' => $this->city->name[$lang] ? $this->city->name[$lang] : "",
            'mobile' => $this->mobile ? $this->mobile : '',
            'user_mobile' => $this->user->mobile ? $this->user->mobile : '',
            'hide_mobile' => $this->hide_mobile,
            'ad_type' => $ad_type,
            'year' => $this->year ? $this->year : '',
            'car_status' => $car_status,
            'installment_destination' => $this->installment_destination ? $this->installment_destination : '',
            'fetis' => $fetis,
            'fuel' => $fuel,
            'double' => $double,
            'km' => $this->km ? $this->km : '',
            'price' => $this->price ? $this->price : '',
            'detail' => $this->detail ? $this->detail : '',
            'lat' => $this->lat ? $this->lat : '',
            'lng' => $this->lng ? $this->lng : '',
            'code' => $this->code ? $this->code : '',
            'views' => $this->views ? (integer)$this->views : 0,
            'status' => $this->status,
            'user_id' => (integer)$this->user_id,
            'user_name' => $this->user->name ? $this->user->name : "",
            'ago' => Carbon::parse($this->created_at)->diffForHumans(),
            'image' => ProductImagesResource::collection($this->images),
            'is_favorite' => $this->is_favorite ? $this->is_favorite : false,
            'is_follower' => $this->is_follower ? $this->is_follower : false,
            'comments' => CommentsResource::collection($this->comments),
            'words_search' => (count($categories) > 0) ? CategoriesResource::collection($categories) : [],
        ];
    }
}
